Server logic for scatterPlot module
Source:R/dittoViz_ScatterPlot_module_server.R
dittoViz_scatterPlotServer.RdServer logic for scatterPlot module
Usage
dittoViz_scatterPlotServer(
id,
data,
hide.inputs = NULL,
hide.tabs = NULL,
manual.colors = NULL,
defaults = NULL
)Arguments
- id
The ID for the Shiny module.
- data
A
reactivecontaining the data frame to plot.- hide.inputs
A character vector of input IDs to hide. These will still be initialized and their values passed to the plot function, but the user will not be able to see/adjust them in the UI.
- hide.tabs
A character vector of tab names to hide. Inputs in these tabs will still be initialized and their values passed to the plot function, but the user will not be able to see/adjust them in the UI.
- manual.colors
A named character vector of colors or a reactive returning a named character vector of colors.
- defaults
A named list of default values for the inputs. When the reset button is clicked, inputs are reset to these values rather than hardcoded fallbacks. Typically the same list passed to the corresponding UI function.