Skip to contents

This function creates an empty ggplot2 or plotly plot and places a user-provided text string in the middle of the plot.

Usage

empty_plot(text = NULL, plotly = FALSE)

Arguments

text

Character scalar to show in plot area.

plotly

Boolean indicating whether to return a plotly object.

Value

Either a ggplot object or a plotly object if plotly = TRUE.

See also

Author

Jared Andrews

Examples

library(VizModules)
empty_plot("No data to display")