Retrieve a model backend from the registry by name.
Value
The backend list (with fit, predict, validate_classes), or
NULL if no backend with that name is registered.
Examples
get_model_backend("lm")
#> $fit
#> function (formula, data, ...)
#> stats::lm(formula, data = data)
#> <bytecode: 0x55b69332cca0>
#> <environment: 0x55b693300328>
#>
#> $predict
#> function (model, newdata)
#> as.numeric(stats::predict(model, newdata = newdata))
#> <bytecode: 0x55b69332cfb0>
#> <environment: 0x55b693300328>
#>
#> $validate_classes
#> [1] "lm"
#>
get_model_backend("nonexistent")
#> NULL