Returns the names of all currently registered model backends. The built-in
backends (lm, glm, loess, nls) are always present; any backends
added via register_model_backend() are included as well.
Returns the names of all currently registered model backends. The built-in
backends (lm, glm, loess, nls) are always present; any backends
added via register_model_backend() are included as well.