Click/brush info output UI component for the ComplexHeatmap module
Source:R/ComplexHeatmap_Heatmap_module_ui.R
ComplexHeatmap_HeatmapInfoOutputUI.RdRenders only the output panel showing information about the clicked or
brushed cell(s) (e.g. row/column names and value), via
InteractiveComplexHeatmap::HeatmapInfoOutput(). See
ComplexHeatmap_HeatmapMainOutputUI() for how the separated output pieces
fit together.
Arguments
- id
The ID for the Shiny module. Must match the
idused forComplexHeatmap_HeatmapServer()and any other output pieces for the same heatmap.- title
Optional panel title.
NULL(the default) omits the title.- width
Panel width in pixels.
- ...
Additional arguments passed to
InteractiveComplexHeatmap::HeatmapInfoOutput().
Examples
library(VizModules)
ComplexHeatmap_HeatmapInfoOutputUI("heatmap", title = "Details")
#> <div id="heatmap_Heatmap_output_wrapper" style="width: 400px">
#> <h5>Details</h5>
#> <div id="heatmap_Heatmap_info" class="shiny-html-output"></div>
#> </div>