This function creates an empty ggplot2 or plotly plot and places a user-provided text string in the middle of the plot.
Examples
library(VizModules)
empty_plot("No data to display")
This function creates an empty ggplot2 or plotly plot and places a user-provided text string in the middle of the plot.
library(VizModules)
empty_plot("No data to display")