A small dataset with five groups, two categorical variables, and three
numeric variables. Used as the default data for plotthis_BarPlotApp()
and plotthis_SplitBarPlotApp().
A small dataset with five groups, two categorical variables, and three
numeric variables. Used as the default data for plotthis_BarPlotApp()
and plotthis_SplitBarPlotApp().