Extract parameter documentation from an R function help page
Source:R/parse_utils.R
get_documentation.RdParses the Rd documentation for a given function and extracts parameter descriptions for specified parameter names.
Arguments
- package_name
A string in the format "package::function" indicating which function's documentation to parse.
- type
The type of documentation section to extract. Currently only "param" is supported.
- selected
A list of parameter names to extract. Note that co-documented parameters (e.g.,
x.byandy.by) should be grouped together in a vector within the list or an error will be thrown byextract_roc_text.- cap
Logical; if TRUE, capitalize the first letter of each description.