Extends or truncates a style vector to match the number of lines being drawn. If the input length doesn't match the target length, uses only the first value for all lines (as documented behavior).
Examples
recycle_line_style(c("red", "blue"), 2, "black")
#> [1] "red" "blue"
recycle_line_style(NULL, 3, "black")
#> [1] "black" "black" "black"