Given the number of facet levels and optional user-supplied
facet.nrow / facet.ncol values, computes the nrows
argument to pass to plotly::subplot.
Value
A positive integer giving the number of rows for
plotly::subplot.
Given the number of facet levels and optional user-supplied
facet.nrow / facet.ncol values, computes the nrows
argument to pass to plotly::subplot.
A positive integer giving the number of rows for
plotly::subplot.