Server logic for ternaryPlot module
Arguments
- id
The ID for the Shiny module.
- data
A
reactivecontaining the data frame to plot. Provide data with numeric columns for the three ternary axes (a, b, c). For multiple traces, include a grouping column.- hide.inputs
A character vector of input IDs to hide. These will still be initialized and their values passed to the plot function, but the user will not be able to see/adjust them in the UI.
- hide.tabs
A character vector of tab names to hide. Inputs in these tabs will still be initialized and their values passed to the plot function, but the user will not be able to see/adjust them in the UI.
- defaults
A named list of default values for the inputs. When the reset button is clicked, inputs are reset to these values rather than hardcoded fallbacks. Typically the same list passed to the corresponding UI function.